#!/etc/opt/openit/perl

use strict;

my $file = "/var/opt/openit/etc/Components/licpoll.xml";

if( ! -f $file ) {
    print "No licpoll.xml. Skipping.";
    exit( 0 );
}

print "Updating licpoll.xml with default product names.\n";

my @lines = slurp_file( $file );

my $i;
foreach my $line( @lines ) {
    if( $line =~ m/default-product-names/ ) {
	print "Configuration already updated.\n";
	exit( 0 );
    }
}

my $found;
for( $i = scalar @lines; $i > 0; $i-- ) {
    if( $lines[ $i - 1 ] =~ m/SubObjects/ ) {
	$found = $i - 1;
	last;
    }
}

if( ! defined $found ) {
    die "Something is wrong with '$file'\n";
}

my $merge = "./files/licpoll-merge.xml";
my @merge = &slurp_file( "$merge" );

splice( @lines, $found, 0, @merge );

&dump_file( "$file.tmp", @lines );
rename "$file.tmp", $file;
exit( 0 );

sub slurp_file {
    my $file = shift @_;

    open( FILE, "<$file" ) or die "unable to open '$file' for reading: $!\n";

    my @lines = ();

    $! = undef;
    my $line;
    while( 1 ) {
	my $line = <FILE>;
	if( $? ) {
	    die "Could not read line from '$file': $!\n";
	}
	if( ! defined $line ) {
	    last;
	}
	push @lines, $line;
    }

    close( FILE );
    return @lines;
}

sub dump_file {
    my $file = shift @_;
    my @lines = @_;

    open( FILE, ">$file" ) or die "unable to open '$file' for writing: $!\n";

    $! = undef;
    while( scalar @lines ) {
	my $line = shift @lines;
	if( ! print FILE $line ) {
	    unlink $file;
	    die "Could not read line from '$file': $!\n";
	}
    }

    close( FILE );
}

